@@ -869,10 +869,6 @@ gnome_font_dialog_init (GnomeFontDialog *fontseldiag)
 	gtk_dialog_set_default_response (GTK_DIALOG (fontseldiag), GTK_RESPONSE_CANCEL);
 
 	gtk_container_set_border_width (GTK_CONTAINER (fontseldiag), 4);
-	/* FIXME: Porting to DISABLE_DEPRECATED left over (Chema) */
-#if 0	
-	gtk_window_set_policy (GTK_WINDOW (fontseldiag), FALSE, TRUE, TRUE);
-#endif	
 
 	fontseldiag->fontsel = gnome_font_selection_new ();
 	gtk_widget_show (fontseldiag->fontsel);
